ClerkThemeColors class
Colors to be used by the theme
Constructors
Properties
- accent → Color
-
link color
final
- altBackground → Color
-
alternate background color
final
- background → Color
-
background color
final
- borderSide → Color
-
border side color
final
- error → Color
-
error color
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Color
-
icon color
final
- lightweightText → Color
-
lightweight text color
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → Color
-
text color
final
Methods
-
lerp(
ClerkThemeColors other, double t) → ClerkThemeColors - lerp
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited